`Elliptical slice sampling
<http://homepages.inf.ed.ac.uk/imurray2/pub/10ess/>`_ for `George
<http://dan.iel.fm/george>`_.

Copyright 2014 Daniel Foreman-Mackey.
Available under the terms of the MIT license (see LICENSE).
